SyncComponent

Trait SyncComponent 

pub trait SyncComponent<F = ()>: Component {
    type Target: Bundle<Effect: NoBundleEffect>;
}
Trait that links components from the main world with output components in the render world. It is used by SyncComponentPlugin.

The marker type F is only used as a way to bypass the orphan rules. To implement the trait for a foreign type you can use a local type as the marker, e.g. the type of the plugin that calls SyncComponentPlugin.

Required Associated Types

type Target: Bundle<Effect: NoBundleEffect>

Describes what components should be removed from the render world if the implementing component is removed.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl SyncComponent for CameraMainTextureUsages

Source

impl SyncComponent for Camera2d

Source

impl SyncComponent for Camera3d

Implementors